@@ -1,5 +1,5 @@
 from .__about__ import __version__
-from .defern import (defern, deferner, defern_this, here)
+from .defern import (defern, deferner, defern_this, here, defer)
 
 
 __all__ = [
@@ -7,5 +7,6 @@ __all__ = [
     "defern",
     "deferner",
     "defern_this",
-    "here"
-]
\ No newline at end of file
+    "here",
+    "defer",
+]
